'''
Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0

Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the "Software"), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
'''

import datetime
import os

import boto3
from ask_sdk_core.skill_builder import SkillBuilder
from ask_sdk_core.utils import is_request_type
from ask_sdk_model.ui import SimpleCard
from boto3.dynamodb.conditions import Key

sb = SkillBuilder()

TARGET_TABLE = os.environ.get("DYNAMO_TABLE", "pet_detection")
TARGET_SENSOR = os.environ.get("SENSOR_NAME", "pet_sensor")


@sb.request_handler(can_handle_func=is_request_type("LaunchRequest"))
def launch_request_handler(handler_input):

    dynamoDB = boto3.resource("dynamodb")
    table = dynamoDB.Table(TARGET_TABLE)
    queryData = table.query(
        KeyConditionExpression=Key("sensor").eq(TARGET_SENSOR),  # 取得するKey情報
        ScanIndexForward=False,  # 昇順か降順か(デフォルトはTrue=昇順)
        Limit=1  # 取得するデータ件数
    )

    if queryData.get('Items'):
        timestr = queryData['Items'][0]['timestamp']
        dt = datetime.datetime.strptime(timestr, '%Y-%m-%dT%H:%M:%S%z')
        speech_text = "{}時{}分です。".format(dt.hour, dt.minute)
    else:
        speech_text = "ごめんなさい、まだわかりません。"

    handler_input.response_builder.speak(speech_text).set_card(
        SimpleCard("Sensor Information", speech_text)).set_should_end_session(
        True)
    return handler_input.response_builder.response


@sb.request_handler(can_handle_func=is_request_type("SessionEndedRequest"))
def session_ended_request_handler(handler_input):
    return handler_input.response_builder.response


@sb.exception_handler(can_handle_func=lambda i, e: True)
def all_exception_handler(handler_input, exception):
    print(exception)
    speech = "問題が発生しました。もう一度言ってください。"
    handler_input.response_builder.speak(speech).ask(speech)
    return handler_input.response_builder.response


lambda_handler = sb.lambda_handler()
